// Copyright 2017 Esri.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import UIKit
import ArcGIS

class ViewController: UIViewController {
    @IBOutlet weak var mapView: AGSMapView!
    private func setupMap() {
        // Init map
        let map = AGSMap(basemapStyle: .arcGISTopographic)
        // Set mapView's view point
        mapView.setViewpoint(AGSViewpoint(latitude: 34.027, longitude: -118.805, scale: 100000))
        // Init portal and portal item
        let portal = AGSPortal(url: URL(string: "https://www.arcgis.com")!, loginRequired: false)
        let portalItem = AGSPortalItem(portal: portal, itemID: "2e4b3df6ba4b44969a3bc9827de746b3")

        // Init layer from portal item, and add layer to map
        let layer = AGSFeatureLayer(item: portalItem, layerID: 0)
        map.operationalLayers.add(layer)
        // Set map view's map
        mapView.map = map
    }

    override func viewDidLoad() {
        super.viewDidLoad()
        setupMap()
    }
}

